@@ -6,14 +6,15 @@
 //  Created by Riccardo Mottola on Tue Jan 16 2007.
 //  Copyright (c) 2007 Carduus. All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify it under the terms of the version 2 of the GNU General Public License as published by the Free Software Foundation.
+// This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 
 #import <AppKit/AppKit.h>
 
 
-@interface PRCGrayscale : NSObject {
+@interface PRCGrayscale : NSObject
+{
     IBOutlet NSWindow *grayWindow;
     IBOutlet NSPopUpButton *methodChoice;
 }
