@@ -5,7 +5,7 @@
 //  Created by Riccardo Mottola on Mon Dec 23 2002.
 //  Copyright (c) 2002-2003-2004 Carduus. All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify it under the terms of the version 2 of the GNU General Public License as published by the Free Software Foundation.
+// This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 
@@ -13,7 +13,8 @@
 #import "PRImage.h"
 
 
-@interface PRTransforms : NSObject {
+@interface PRTransforms : NSObject
+{
 
 }
 
