@@ -5,7 +5,7 @@
 //  Created by Riccardo Mottola on Thu Dec 12 2002.
 //  Copyright (c) 2002-2005 Carduus. All rights reserved.
 //
-// This program is free software; you can redistribute it and/or modify it under the terms of the version 2 of the GNU General Public License as published by the Free Software Foundation.
+// This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 #import "PRWindowController.h"
@@ -139,7 +139,6 @@
     currentWindowSize = currentWinContentRect.size;
     minWinSize = [currWin minSize];
     NSLog(@"current window size: %f x  %f", currentWindowSize.width, currentWindowSize.height);
-    NSLog(@"min window size: %f x  %f", minWinSize.width, minWinSize.height);
     newWinSize = currentWindowSize;
 
     /* get size of the visible part of the view */
@@ -151,7 +150,6 @@
 
     /* get the image size */
     currImageSize = [currImage size];
-    NSLog(@"current image size: %f x  %f", currImageSize.width, currImageSize.height);
 
     /* resize if image is smaller */
     if (currImageSize.width < currViewSize.width)
